@@ -51,7 +51,7 @@ event_sources.json and ${program.eventFile} files as needed.`)
   }
 
   run (program) {
-    if (!['nodejs10.x', 'nodejs12.x', 'nodejs14.x'].includes(program.runtime)) {
+    if (!['nodejs12.x', 'nodejs14.x'].includes(program.runtime)) {
       console.error(`Runtime [${program.runtime}] is not supported.`)
       process.exit(254)
     }
@@ -566,7 +566,7 @@ Emulate only the body of the API Gateway event.
     }
   }
 
-  _uploadExisting (lambda, params) {
+  async _uploadExisting (lambda, params) {
     const functionCodeParams = Object.assign({
       FunctionName: params.FunctionName,
       Publish: params.Publish
@@ -594,29 +594,30 @@ Emulate only the body of the API Gateway event.
       delete functionConfigParams.Layers
     }
 
-    return new Promise((resolve, reject) => {
-      const updateConfigRequest = lambda.updateFunctionConfiguration(
-        functionConfigParams,
-        (err, configResponse) => {
-          if (err) return reject(err)
-
-          const updateCodeRequest = lambda.updateFunctionCode(functionCodeParams, (err) => {
-            if (err) return reject(err)
-            resolve(configResponse)
-          })
-
-          updateCodeRequest.on('retry', (response) => {
-            console.log(response.error.message)
-            console.log('=> Retrying')
-          })
-        }
-      )
-
-      updateConfigRequest.on('retry', (response) => {
-        console.log(response.error.message)
-        console.log('=> Retrying')
-      })
+    const updateConfigRequest = lambda.updateFunctionConfiguration(functionConfigParams)
+    updateConfigRequest.on('retry', (response) => {
+      console.log(response.error.message)
+      console.log('=> Retrying')
     })
+    const updateConfigResponse = await updateConfigRequest.promise()
+
+    // Wait for the `Configuration.LastUpdateStatus` to change from `InProgress` to `Successful`.
+    for (let i = 0; i < 10; i++) {
+      const data = await lambda.getFunction({ FunctionName: params.FunctionName }).promise()
+      if (data.Configuration.LastUpdateStatus === 'Successful') {
+        break
+      }
+      await new Promise((resolve) => setTimeout(resolve, 3000))
+    }
+
+    const updateCodeRequest = lambda.updateFunctionCode(functionCodeParams)
+    updateCodeRequest.on('retry', (response) => {
+      console.log(response.error.message)
+      console.log('=> Retrying')
+    })
+    await updateCodeRequest.promise()
+
+    return updateConfigResponse
   }
 
   _uploadNew (lambda, params) {
@@ -657,9 +658,13 @@ Emulate only the body of the API Gateway event.
   _archivePrebuilt (program) {
     const codeDirectory = this._codeDirectory()
 
-    return this._fileCopy(program, program.prebuiltDirectory, codeDirectory, false).then(() => {
-      console.log('=> Zipping deployment package')
-      return this._zip(program, codeDirectory)
+    return Promise.resolve().then(() => {
+      return this._cleanDirectory(codeDirectory, program.keepNodeModules)
+    }).then(() => {
+      return this._fileCopy(program, program.prebuiltDirectory, codeDirectory, false).then(() => {
+        console.log('=> Zipping deployment package')
+        return this._zip(program, codeDirectory)
+      })
     })
   }
 
