@@ -52,7 +52,7 @@ const lambdaMockSettings = {
   addPermission: {},
   getFunction: {
     Code: {},
-    Configuration: {},
+    Configuration: { LastUpdateStatus: 'Successful' },
     FunctionArn: 'Lambda.getFunction.mock.FunctionArn'
   },
   createFunction: {
@@ -149,7 +149,7 @@ describe('lib/main', function () {
   })
 
   it('version should be set', () => {
-    assert.equal(lambda.version, '0.19.1')
+    assert.equal(lambda.version, '0.20.0')
   })
 
   describe('_codeDirectory', () => {
@@ -591,20 +591,15 @@ describe('lib/main', function () {
   })
 
   describe('_npmInstall', function () {
-    _timeout({ this: this, sec: 30 }) // ci should be faster than install
+    _timeout({ this: this, sec: 60 }) // ci should be faster than install
 
     // npm treats files as packages when installing, and so removes them.
     // Test with `devDependencies` packages that are not installed with the `--production` option.
     const nodeModulesMocha = path.join(codeDirectory, 'node_modules', 'mocha')
 
-    beforeEach(() => {
-      return lambda._cleanDirectory(codeDirectory).then(() => {
-        fs.copySync(
-          path.join('node_modules', 'aws-sdk'),
-          path.join(codeDirectory, 'node_modules', 'aws-sdk')
-        )
-        return lambda._fileCopy(program, '.', codeDirectory, true)
-      })
+    beforeEach(async () => {
+      await lambda._cleanDirectory(codeDirectory)
+      await lambda._fileCopy(program, '.', codeDirectory, false)
     })
 
     describe('when package-lock.json does exist', () => {
@@ -865,6 +860,24 @@ describe('lib/main', function () {
         })
       })
     })
+
+    it('cleans the temporary directory before running `_archivePrebuilt`', function () {
+      _timeout({ this: this, sec: 30 }) // give it time to zip
+      const buildDir = '.build_' + Date.now()
+      const codeDir = lambda._codeDirectory()
+      const tmpFile = path.join(codeDir, 'deleteme')
+      after(() => fs.removeSync(buildDir))
+
+      fs.mkdirSync(codeDir, { recursive: true })
+      fs.writeFileSync(tmpFile, '...')
+      fs.mkdirSync(buildDir)
+      fs.writeFileSync(path.join(buildDir, 'test'), '...')
+
+      program.prebuiltDirectory = buildDir
+      return lambda._archive(program).then((_data) => {
+        assert.isNotTrue(fs.existsSync(tmpFile))
+      })
+    })
   })
 
   describe('_readArchive', () => {
